pub struct FetchConfig {
pub refresh_hours: Option<u32>,
pub follow_links: Option<FollowLinks>,
pub allowlist: Option<Vec<String>>,
}Expand description
Per-source fetching behavior overrides.
These settings override the global defaults for fetching behavior.
Any None values will use the corresponding global default setting.
Fields
refresh_hours: Option<u32>Override for refresh interval in hours.
If Some, overrides the global refresh_hours setting for this source.
If None, uses the global default.
follow_links: Option<FollowLinks>Override for link following policy.
If Some, overrides the global follow_links setting for this source.
If None, uses the global default.
allowlist: Option<Vec<String>>Override for allowed domains list.
If Some, overrides the global allowlist setting for this source.
If None, uses the global default. Only used when follow_links is Allowlist.